@@ -523,6 +523,14 @@ class _StringExpression(BaseExpression):
             f'{self.as_subexpression()} {"!has_cs" if case_sensitive else "!has"} {_to_kql(exp, True)}'
         ))
 
+    def has_any(self, other: Union[List, Tuple]) -> '_BooleanExpression':
+        """
+        https://docs.microsoft.com/en-us/azure/data-explorer/kusto/query/has-anyoperator
+        Please notice that this implementation does not support tabular expression inputs currently
+        """
+        assert isinstance(other, (List, Tuple)), "Compared array must be a list of tabular, scalar, or literal expressions"
+        return _BooleanExpression(KQL(f'{self.kql} has_any ({", ".join(map(_to_kql, other))})'))
+
 
 @_plain_expression(_KustoType.DATETIME)
 class _DatetimeExpression(BaseExpression):
@@ -1046,7 +1054,7 @@ class ColumnGenerator:
         return _AnyTypeColumn(name, quote=True)
 
 
-# Recommended usage: from pykusto.expressions import column_generator as col
+# Recommended usage: from pykusto import column_generator as col
 # TODO: Is there a way to enforce this to be a singleton?
 column_generator = ColumnGenerator()
 
